@@ -8,15 +8,25 @@ from __future__ import annotations
 from typing import Any, Dict
 
 from ..const import GitHubRequestKwarg
+from ..models.organization import GitHubOrganizationMinimalModel
 from ..models.repository import GitHubRepositoryModel
 from ..models.response import GitHubResponseModel
 from ..models.user import GitHubAuthenticatedUserModel
 from .base import BaseNamespace
+from .projects import GitHubUserProjectsNamespace
 
 
 class GitHubUserNamespace(BaseNamespace):
     """Methods for the user namespace"""
 
+    def __post_init__(self) -> None:
+        self._projects = GitHubUserProjectsNamespace(self._client)
+
+    @property
+    def projects(self) -> GitHubUserProjectsNamespace:
+        """Property to access the users projects namespace"""
+        return self._projects
+
     async def get(
         self,
         **kwargs: Dict[GitHubRequestKwarg, Any],
@@ -72,3 +82,17 @@ class GitHubUserNamespace(BaseNamespace):
         response.data = [GitHubRepositoryModel(data) for data in response.data]
 
         return response
+
+    async def orgs(
+        self,
+        **kwargs: Dict[GitHubRequestKwarg, Any],
+    ) -> GitHubResponseModel[list[GitHubOrganizationMinimalModel]]:
+        """
+         List public organization memberships for the specified user.
+
+
+        https://docs.github.com/en/rest/reference/orgs#list-organizations-for-the-authenticated-user
+        """
+        response = await self._client.async_call_api(endpoint="/user/orgs", **kwargs)
+        response.data = [GitHubOrganizationMinimalModel(data) for data in response.data or []]
+        return response
